FULL_VERSION  = 2.7.2.8
MAJOR_VERSION = 2.7.2

SHLIB      = libg++.so.$(FULL_VERSION)
MSHLINK    = libg++.so.$(MAJOR_VERSION)
BUILD_LIBS = $(ARLIB) $(SHLIB) $(SHLINK) $(MSHLINK)
SHFLAGS    = -Wl,-soname,$(MSHLINK)
